==> kinetophone-0.2.0.tar.gz: kinetophone-0.2.0/src/base/error/Record_error.hpp <==
// Record_error.hpp
//
// Copyright 2011-2012 Roan Trail, Inc.
//
// This file is part of Kinetophone.
//
// Kinetophone is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published
// by the Free Software Foundation, either version 2 of the License,
// or (at your option) any later version.
//
// Kinetophone is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.  You should have received
// a copy of the GNU General Public License along with Kinetophone. If
// not, see <http://www.gnu.org/licenses/>.

#ifndef RECORD_ERROR_HPP_
#define RECORD_ERROR_HPP_

#include "Error.hpp"

namespace Roan_trail
{
  namespace Recorder
  {
    class Record_error : public Error
    {
    public:
      // constructor/destructor/copy/clone
      Record_error(const char* file,
                   const char* function,
                   int line,
                   int code,
                   const Error* base_error = 0);
      Record_error(const char* file,
                   const char* function,
                   int line,
                   int code,
                   const string& diagnostic,
                   const string& file_path = "",
                   const Error* base_error = 0);
      virtual Record_error* clone() const { return new Record_error(*this); }
      // other
      virtual string error_class() const { return "Record_error"; }
      // error codes
      static const int none              =  0; // code for none should always be 0
      static const int general           =  1; // code for general error should always be 1
      static const int startup           =  2;
      static const int record_callback   =  3;
      static const int record_write      =  4;
      static const int open_input_stream =  5;
      static const int record            =  6;
      static const int pause             =  7;
      static const int mute              =  8;
      static const int stop              =  9;
      static const int invalid_state     = 10;
      static const int parse_segments    = 11;
      static const int load              = 12;
      static const int save              = 13;
      static const int shutdown          = 14;
    protected:
      // invariant check
      bool mf_invariant(bool check_base_class = true) const;
    private:
      // prevent compiler from generating
      Record_error operator=(const Record_error& e);
    };
  }
}

#endif // RECORD_ERROR_HPP_

==> kinetophone-0.3.0.tar.gz: kinetophone-0.3.0/src/base/error/Record_error.hpp <==
// Record_error.hpp
//
// Copyright 2011-2012 Roan Trail, Inc.
//
// This file is part of Kinetophone.
//
// Kinetophone is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published
// by the Free Software Foundation, either version 2 of the License,
// or (at your option) any later version.
//
// Kinetophone is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.  You should have received
// a copy of the GNU General Public License along with Kinetophone. If
// not, see <http://www.gnu.org/licenses/>.

#ifndef RECORD_ERROR_HPP_
#define RECORD_ERROR_HPP_

#include "Error.hpp"
#include <string>

namespace Roan_trail
{
  namespace Recorder
  {
    class Record_error : public Error
    {
    public:
      // constructor/destructor/copy/clone
      Record_error(const char* file,
                   const char* function,
                   int line,
                   int code,
                   const Error* base_error = 0);
      Record_error(const char* file,
                   const char* function,
                   int line,
                   int code,
                   const std::string& diagnostic,
                   const std::string& file_path = "",
                   const Error* base_error = 0);
      virtual Record_error* clone() const { return new Record_error(*this); }
      // other
      virtual std::string error_class() const { return "Record_error"; }
      // error codes
      static const int none              =  0; // code for none should always be 0
      static const int general           =  1; // code for general error should always be 1
      static const int startup           =  2;
      static const int record_callback   =  3;
      static const int record_write      =  4;
      static const int open              =  5;
      static const int open_input_stream =  6;
      static const int record            =  7;
      static const int pause             =  8;
      static const int mute              =  9;
      static const int stop              = 10;
      static const int invalid_state     = 11;
      static const int parse_segments    = 12;
      static const int load              = 13;
      static const int save              = 14;
      static const int shutdown          = 15;
    protected:
      // invariant check
      bool mf_invariant(bool check_base_class = true) const;
    private:
      // prevent compiler from generating
      Record_error operator=(const Record_error& e);
    };
  }
}

#endif // RECORD_ERROR_HPP_
